

# Neuromodcell

[![Join the chat at https://gitter.im/Neuro_modulation/community](https://badges.gitter.im/Neuro_modulation/community.svg)](https://gitter.im/Neuro_modulation/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![codecov](https://codecov.io/gh/jofrony/Neuromodulation/branch/main/graph/badge.svg?token=LKUJ5SC457)](https://codecov.io/gh/jofrony/Neuromodulation)


Optimising multicompartmental neurons according to different neuromodulators.

### Tutorial for setting up neuromodulation for single cell models

See examples for Jupyter Notebook on dSPN optimization

### Example of neuromodulation of striatal projection neuron


